# SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later


import click
from clapper.click import ResourceOption, verbosity_option
from clapper.logging import setup
from mednet.libs.common.scripts.click import ConfigCommand
from mednet.libs.common.scripts.predict import predict as predict_script
from mednet.libs.common.scripts.predict import reusable_options

logger = setup(__name__.split(".")[0], format="%(levelname)s: %(message)s")


@click.command(
    entry_point_group="mednet.libs.classification.config",
    cls=ConfigCommand,
    epilog="""Examples:

1. Run prediction on an existing DataModule configuration:

   .. code:: sh

      mednet predict -vv pasa montgomery --weight=path/to/model.ckpt --output=path/to/predictions.json

2. Enable multi-processing data loading with 6 processes:

   .. code:: sh

      mednet predict -vv pasa montgomery --parallel=6 --weight=path/to/model.ckpt --output=path/to/predictions.json

""",
)
@reusable_options
@verbosity_option(logger=logger, cls=ResourceOption, expose_value=False)
def predict(
    output,
    model,
    datamodule,
    batch_size,
    device,
    weight,
    parallel,
    **_,
) -> None:  # numpydoc ignore=PR01
    """Run inference (generates scores) on all input images, using a pre-trained model."""
    predict_script(
        output,
        model,
        datamodule,
        batch_size,
        device,
        weight,
        parallel,
        **_,
    )
