import click
from clapper.click import ResourceOption, verbosity_option
from clapper.logging import setup
from mednet.libs.common.scripts.click import ConfigCommand
from mednet.libs.common.scripts.train import reusable_options
from mednet.libs.common.scripts.train import train as train_script

logger = setup("mednet", format="%(levelname)s: %(message)s")


@click.command(
    entry_point_group="mednet.libs.classification.config",
    cls=ConfigCommand,
    epilog="""Examples:

1. Train a pasa model with the montgomery dataset, on a GPU (``cuda:0``), using
   simple elastic deformation augmentations:

   .. code:: sh

      mednet train -vv pasa elastic montgomery --batch-size=4 --device="cuda:0"
""",
)
@reusable_options
@verbosity_option(logger=logger, cls=ResourceOption, expose_value=False)
def train(
    model,
    output_folder,
    epochs,
    batch_size,
    accumulate_grad_batches,
    drop_incomplete_batch,
    datamodule,
    validation_period,
    device,
    cache_samples,
    seed,
    parallel,
    monitoring_interval,
    balance_classes,
    augmentations,
    **_,
) -> None:  # numpydoc ignore=PR01
    """Train an CNN to perform image classification.

    Training is performed for a configurable number of epochs, and
    generates checkpoints.  Checkpoints are model files with a .ckpt
    extension that are used in subsequent tasks or from which training
    can be resumed.
    """
    train_script(
        model,
        output_folder,
        epochs,
        batch_size,
        accumulate_grad_batches,
        drop_incomplete_batch,
        datamodule,
        validation_period,
        device,
        cache_samples,
        seed,
        parallel,
        monitoring_interval,
        balance_classes,
        **_,
    )
