# SPDX-FileCopyrightText: Copyright © 2024 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later
"""Little W-Net for image segmentation.

The Little W-Net architecture contains roughly around 70k parameters and
closely matches (or outperforms) other more complex techniques.

Reference: [GALDRAN-2020]_
"""

from mednet.libs.segmentation.models.losses import MultiWeightedBCELogitsLoss
from mednet.libs.segmentation.models.lwnet import LittleWNet
from torch.optim import Adam

max_lr = 0.01  # start
min_lr = 1e-08  # valley
cycle = 50  # epochs for a complete scheduling cycle

model = LittleWNet(
    train_loss=MultiWeightedBCELogitsLoss(),
    validation_loss=MultiWeightedBCELogitsLoss(),
    optimizer_type=Adam,
    optimizer_arguments=dict(lr=max_lr),
    augmentation_transforms=[],
    crop_size=544,
)
